@@ -1,7 +1,6 @@
-use proc_macro2::Span as Span2;
-use proc_macro2::TokenStream as TokenStream2;
+use proc_macro2::{Span as Span2, TokenStream as TokenStream2};
 use syn::{
-    punctuated::Punctuated, spanned::Spanned, token, Expr, ExprClosure, Generics, Ident, Lit, Path,
+    punctuated::Punctuated, token, token::Mut, Expr, ExprClosure, Generics, Ident, Lit, Path,
 };
 
 use crate::args::Args;
@@ -20,7 +19,7 @@ pub(super) enum PropertyType {
     Expr(Expr),
     Value(Lit),
     Track(Tracker),
-    Component(Expr),
+    Parent(Expr),
     Args(Args<Expr>),
     Connect(ExprClosure),
     ConnectComponent(ExprClosure),
@@ -35,22 +34,17 @@ pub enum PropertyName {
     Path(Path),
 }
 
-impl Spanned for PropertyName {
-    fn span(&self) -> Span2 {
-        match self {
-            PropertyName::Ident(ident) => ident.span(),
-            PropertyName::Path(path) => path.span(),
-        }
-    }
-}
-
 #[derive(Debug)]
 pub(super) struct Property {
+    /// Either a path or just an ident
     pub name: PropertyName,
     pub ty: PropertyType,
     pub generics: Option<Generics>,
+    /// Optional arguments like param_name(arg1, arg2, ...)
     pub args: Option<Args<Expr>>,
+    /// Assign with an ?
     pub optional_assign: bool,
+    /// Iterate through elements to generate tokens
     pub iterative: bool,
 }
 
@@ -64,35 +58,24 @@ pub(super) struct WidgetFunc {
     pub path_segments: Vec<Ident>,
     pub args: Option<Punctuated<Expr, token::Comma>>,
     pub ty: Option<Vec<Ident>>,
-}
-
-impl Spanned for WidgetFunc {
-    fn span(&self) -> Span2 {
-        self.path_segments
-            .first()
-            .expect("Expected path segments in WidgetFunc")
-            .span()
-    }
+    pub span: Span2,
 }
 
 #[derive(Debug)]
 pub(super) struct Widget {
+    pub mutable: Option<Mut>,
     pub name: Ident,
     pub func: WidgetFunc,
     pub properties: Properties,
     pub wrapper: Option<Ident>,
     pub assign_as_ref: bool,
+    pub returned_widget: Option<ReturnedWidget>,
 }
 
-impl<'a> Widget {
-    pub fn get_widget_list(&'a self, widgets: &mut Vec<&'a Widget>) {
-        widgets.push(self);
-
-        for prop in &self.properties.properties {
-            let ty = &prop.ty;
-            if let PropertyType::Widget(widget) = ty {
-                widget.get_widget_list(widgets);
-            }
-        }
-    }
+#[derive(Debug)]
+pub(super) struct ReturnedWidget {
+    pub name: Ident,
+    pub ty: Option<Path>,
+    pub properties: Properties,
+    pub is_optional: bool,
 }
